# Changelog

## 6.0.0 (2025-02-04)

Full Changelog: [v5.0.0...v6.0.0](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/compare/v5.0.0...v6.0.0)

### Features

* **api:** update via SDK Studio ([#6](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/6)) ([2f9923b](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/2f9923bd9989785ee26457bf4d98644732ebd0f1))

## 5.0.0 (2025-02-04)

Full Changelog: [v0.0.1-alpha.0...v5.0.0](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/compare/v0.0.1-alpha.0...v5.0.0)

### Chores

* go live ([#1](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/1)) ([839a103](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/839a10374ebfdcc038aeb4f98e66f9ed94f2de18))
* update SDK settings ([#3](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/issues/3)) ([66cb8ec](https://github.com/BrainbaseHQ/brainbase-labs-python-sdk/commit/66cb8ec4118e474cb247ac45272396e5eff8bca3))
